/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2013 by
 * + Christian-Albrechts-University of Kiel
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.kiml.formats.json;

import com.google.common.base.Objects;
import com.google.common.collect.Maps;
import de.cau.cs.kieler.core.kgraph.KEdge;
import de.cau.cs.kieler.core.kgraph.KLabel;
import de.cau.cs.kieler.core.kgraph.KNode;
import de.cau.cs.kieler.core.kgraph.KPort;
import de.cau.cs.kieler.core.properties.IProperty;
import de.cau.cs.kieler.kiml.formats.IGraphTransformer;
import de.cau.cs.kieler.kiml.formats.TransformationData;
import de.cau.cs.kieler.kiml.formats.json.JsonExtensions;
import de.cau.cs.kieler.kiml.klayoutdata.KEdgeLayout;
import de.cau.cs.kieler.kiml.klayoutdata.KInsets;
import de.cau.cs.kieler.kiml.klayoutdata.KLayoutData;
import de.cau.cs.kieler.kiml.klayoutdata.KPoint;
import de.cau.cs.kieler.kiml.klayoutdata.KShapeLayout;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.common.util.EMap;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.ObjectExtensions;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;
import org.json.JSONArray;
import org.json.JSONObject;

/**
 * Exporter from KNode to json.
 * 
 * @author uru
 */
@SuppressWarnings("all")
public class JsonExporter implements IGraphTransformer<KNode, JSONObject> {
  @Extension
  private JsonExtensions _jsonExtensions = new JsonExtensions();
  
  private final Map<KNode, String> nodeIdMap = Maps.<KNode, String>newHashMap();
  
  private final Map<KPort, String> portIdMap = Maps.<KPort, String>newHashMap();
  
  private final Map<KEdge, String> edgeIdMap = Maps.<KEdge, String>newHashMap();
  
  private final Map<KNode, JSONObject> nodeJsonMap = Maps.<KNode, JSONObject>newHashMap();
  
  private final Map<KPort, JSONObject> portJsonMap = Maps.<KPort, JSONObject>newHashMap();
  
  private final Map<KEdge, JSONObject> edgeJsonMap = Maps.<KEdge, JSONObject>newHashMap();
  
  private int nodeIdCounter = 0;
  
  private int portIdCounter = 0;
  
  private int edgeIdCounter = 0;
  
  public void transform(final TransformationData<KNode, JSONObject> data) {
    try {
      this.init();
      final JSONObject jsonGraph = new JSONObject();
      jsonGraph.put("id", "root");
      final JSONArray jsonArray = new JSONArray();
      KNode _sourceGraph = data.getSourceGraph();
      this.transformNode(_sourceGraph, jsonArray);
      KNode _sourceGraph_1 = data.getSourceGraph();
      this.transformEdges(_sourceGraph_1);
      List<JSONObject> _targetGraphs = data.getTargetGraphs();
      Object _get = jsonArray.get(0);
      _targetGraphs.add(((JSONObject) _get));
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  private int init() {
    int _xblockexpression = (int) 0;
    {
      this.nodeIdMap.clear();
      this.portIdMap.clear();
      this.edgeIdMap.clear();
      this.nodeJsonMap.clear();
      this.portJsonMap.clear();
      this.edgeJsonMap.clear();
      this.nodeIdCounter = 0;
      this.portIdCounter = 0;
      _xblockexpression = this.edgeIdCounter = 0;
    }
    return _xblockexpression;
  }
  
  private void transformNode(final KNode node, final JSONArray array) {
    try {
      final JSONObject jsonObj = this.createAndRegister(node);
      array.put(jsonObj);
      final JSONArray labels = new JSONArray();
      jsonObj.put("labels", labels);
      EList<KLabel> _labels = node.getLabels();
      final Procedure1<KLabel> _function = new Procedure1<KLabel>() {
        public void apply(final KLabel it) {
          JsonExporter.this.transformLabel(it, labels);
        }
      };
      IterableExtensions.<KLabel>forEach(_labels, _function);
      KShapeLayout _layout = this._jsonExtensions.layout(node);
      this.transferShapeLayout(_layout, jsonObj);
      final JSONArray ports = new JSONArray();
      jsonObj.put("ports", ports);
      EList<KPort> _ports = node.getPorts();
      final Procedure1<KPort> _function_1 = new Procedure1<KPort>() {
        public void apply(final KPort it) {
          JsonExporter.this.transformPort(it, ports);
        }
      };
      IterableExtensions.<KPort>forEach(_ports, _function_1);
      final JSONArray children = new JSONArray();
      jsonObj.put("children", children);
      EList<KNode> _children = node.getChildren();
      final Procedure1<KNode> _function_2 = new Procedure1<KNode>() {
        public void apply(final KNode it) {
          JsonExporter.this.transformNode(it, children);
        }
      };
      IterableExtensions.<KNode>forEach(_children, _function_2);
      KShapeLayout _layout_1 = this._jsonExtensions.layout(node);
      this.transformProperties(_layout_1, jsonObj);
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  private void transformPort(final KPort port, final JSONArray array) {
    try {
      final JSONObject jsonObj = this.createAndRegister(port);
      array.put(jsonObj);
      final JSONArray labels = new JSONArray();
      jsonObj.put("labels", labels);
      EList<KLabel> _labels = port.getLabels();
      final Procedure1<KLabel> _function = new Procedure1<KLabel>() {
        public void apply(final KLabel it) {
          JsonExporter.this.transformLabel(it, labels);
        }
      };
      IterableExtensions.<KLabel>forEach(_labels, _function);
      KShapeLayout _layout = this._jsonExtensions.layout(port);
      this.transformProperties(_layout, jsonObj);
      KShapeLayout _layout_1 = this._jsonExtensions.layout(port);
      this.transferShapeLayout(_layout_1, jsonObj);
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  private void transformEdges(final KNode node) {
    try {
      final JSONObject jsonObj = this.nodeJsonMap.get(node);
      final JSONArray edges = new JSONArray();
      jsonObj.put("edges", edges);
      EList<KEdge> _outgoingEdges = node.getOutgoingEdges();
      final Procedure1<KEdge> _function = new Procedure1<KEdge>() {
        public void apply(final KEdge it) {
          JsonExporter.this.transformEdge(it, edges);
        }
      };
      IterableExtensions.<KEdge>forEach(_outgoingEdges, _function);
      EList<KNode> _children = node.getChildren();
      final Procedure1<KNode> _function_1 = new Procedure1<KNode>() {
        public void apply(final KNode it) {
          JsonExporter.this.transformEdges(it);
        }
      };
      IterableExtensions.<KNode>forEach(_children, _function_1);
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  private void transformEdge(final KEdge edge, final JSONArray array) {
    try {
      final JSONObject jsonObj = this.createAndRegister(edge);
      array.put(jsonObj);
      final JSONArray labels = new JSONArray();
      jsonObj.put("labels", labels);
      EList<KLabel> _labels = edge.getLabels();
      final Procedure1<KLabel> _function = new Procedure1<KLabel>() {
        public void apply(final KLabel it) {
          JsonExporter.this.transformLabel(it, labels);
        }
      };
      IterableExtensions.<KLabel>forEach(_labels, _function);
      KEdgeLayout _layout = this._jsonExtensions.layout(edge);
      this.transformProperties(_layout, jsonObj);
      KNode _source = edge.getSource();
      String _get = this.nodeIdMap.get(_source);
      final Procedure1<String> _function_1 = new Procedure1<String>() {
        public void apply(final String it) {
          try {
            jsonObj.put("source", it);
          } catch (Throwable _e) {
            throw Exceptions.sneakyThrow(_e);
          }
        }
      };
      ObjectExtensions.<String>operator_doubleArrow(_get, _function_1);
      KNode _target = edge.getTarget();
      String _get_1 = this.nodeIdMap.get(_target);
      final Procedure1<String> _function_2 = new Procedure1<String>() {
        public void apply(final String it) {
          try {
            jsonObj.put("target", it);
          } catch (Throwable _e) {
            throw Exceptions.sneakyThrow(_e);
          }
        }
      };
      ObjectExtensions.<String>operator_doubleArrow(_get_1, _function_2);
      KPort _sourcePort = edge.getSourcePort();
      String _get_2 = this.portIdMap.get(_sourcePort);
      final Procedure1<String> _function_3 = new Procedure1<String>() {
        public void apply(final String it) {
          try {
            boolean _notEquals = (!Objects.equal(it, null));
            if (_notEquals) {
              jsonObj.put("sourcePort", it);
            }
          } catch (Throwable _e) {
            throw Exceptions.sneakyThrow(_e);
          }
        }
      };
      ObjectExtensions.<String>operator_doubleArrow(_get_2, _function_3);
      KPort _targetPort = edge.getTargetPort();
      String _get_3 = this.portIdMap.get(_targetPort);
      final Procedure1<String> _function_4 = new Procedure1<String>() {
        public void apply(final String it) {
          try {
            boolean _notEquals = (!Objects.equal(it, null));
            if (_notEquals) {
              jsonObj.put("targetPort", it);
            }
          } catch (Throwable _e) {
            throw Exceptions.sneakyThrow(_e);
          }
        }
      };
      ObjectExtensions.<String>operator_doubleArrow(_get_3, _function_4);
      final JSONObject sourcePoint = new JSONObject();
      KEdgeLayout _layout_1 = this._jsonExtensions.layout(edge);
      KPoint _sourcePoint = _layout_1.getSourcePoint();
      float _x = _sourcePoint.getX();
      sourcePoint.put("x", _x);
      KEdgeLayout _layout_2 = this._jsonExtensions.layout(edge);
      KPoint _sourcePoint_1 = _layout_2.getSourcePoint();
      float _y = _sourcePoint_1.getY();
      sourcePoint.put("y", _y);
      jsonObj.put("sourcePoint", sourcePoint);
      final JSONObject targetPoint = new JSONObject();
      KEdgeLayout _layout_3 = this._jsonExtensions.layout(edge);
      KPoint _targetPoint = _layout_3.getTargetPoint();
      float _x_1 = _targetPoint.getX();
      targetPoint.put("x", _x_1);
      KEdgeLayout _layout_4 = this._jsonExtensions.layout(edge);
      KPoint _targetPoint_1 = _layout_4.getTargetPoint();
      float _y_1 = _targetPoint_1.getY();
      targetPoint.put("y", _y_1);
      jsonObj.put("targetPoint", targetPoint);
      final JSONArray bends = new JSONArray();
      KEdgeLayout _layout_5 = this._jsonExtensions.layout(edge);
      EList<KPoint> _bendPoints = _layout_5.getBendPoints();
      final Procedure1<KPoint> _function_5 = new Procedure1<KPoint>() {
        public void apply(final KPoint pnt) {
          try {
            final JSONObject jsonPnt = new JSONObject();
            float _x = pnt.getX();
            jsonPnt.put("x", _x);
            float _y = pnt.getY();
            jsonPnt.put("y", _y);
            bends.put(jsonPnt);
          } catch (Throwable _e) {
            throw Exceptions.sneakyThrow(_e);
          }
        }
      };
      IterableExtensions.<KPoint>forEach(_bendPoints, _function_5);
      if (jsonObj!=null) {
        jsonObj.put("bendPoints", bends);
      }
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  private void transformLabel(final KLabel label, final JSONArray array) {
    try {
      final JSONObject jsonLabel = new JSONObject();
      String _text = label.getText();
      jsonLabel.put("text", _text);
      KShapeLayout _layout = this._jsonExtensions.layout(label);
      this.transformProperties(_layout, jsonLabel);
      KShapeLayout _layout_1 = this._jsonExtensions.layout(label);
      this.transferShapeLayout(_layout_1, jsonLabel);
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  private void transformProperties(final KLayoutData holder, final JSONObject parent) {
    try {
      final JSONObject jsonProps = new JSONObject();
      parent.put("properties", jsonProps);
      EMap<IProperty<?>, Object> _properties = holder.getProperties();
      Set<Map.Entry<IProperty<?>, Object>> _entrySet = _properties.entrySet();
      final Procedure1<Map.Entry<IProperty<?>, Object>> _function = new Procedure1<Map.Entry<IProperty<?>, Object>>() {
        public void apply(final Map.Entry<IProperty<?>, Object> p) {
          try {
            IProperty<?> _key = p.getKey();
            String _id = _key.getId();
            jsonProps.put(_id, "");
          } catch (Throwable _e) {
            throw Exceptions.sneakyThrow(_e);
          }
        }
      };
      IterableExtensions.<Map.Entry<IProperty<?>, Object>>forEach(_entrySet, _function);
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public void transferLayout(final TransformationData<KNode, JSONObject> data) {
    throw new UnsupportedOperationException("TODO: auto-generated method stub");
  }
  
  private JSONObject transferShapeLayout(final KShapeLayout layout, final JSONObject jsonObj) {
    try {
      JSONObject _xblockexpression = null;
      {
        if (jsonObj!=null) {
          float _xpos = layout.getXpos();
          jsonObj.put("x", _xpos);
        }
        if (jsonObj!=null) {
          float _ypos = layout.getYpos();
          jsonObj.put("y", _ypos);
        }
        if (jsonObj!=null) {
          float _width = layout.getWidth();
          jsonObj.put("width", _width);
        }
        if (jsonObj!=null) {
          float _height = layout.getHeight();
          jsonObj.put("height", _height);
        }
        final KInsets insets = layout.getInsets();
        JSONObject _xifexpression = null;
        boolean _notEquals = (!Objects.equal(insets, null));
        if (_notEquals) {
          JSONObject _xblockexpression_1 = null;
          {
            JSONObject _optJSONObject = null;
            if (jsonObj!=null) {
              _optJSONObject=jsonObj.optJSONObject("padding");
            }
            JSONObject padding = _optJSONObject;
            boolean _equals = Objects.equal(padding, null);
            if (_equals) {
              JSONObject _jSONObject = new JSONObject();
              padding = _jSONObject;
              if (jsonObj!=null) {
                jsonObj.put("padding", padding);
              }
            }
            if (padding!=null) {
              float _left = insets.getLeft();
              padding.put("left", _left);
            }
            if (padding!=null) {
              float _top = insets.getTop();
              padding.put("top", _top);
            }
            if (padding!=null) {
              float _right = insets.getRight();
              padding.put("right", _right);
            }
            JSONObject _put = null;
            if (padding!=null) {
              float _bottom = insets.getBottom();
              _put=padding.put("bottom", _bottom);
            }
            _xblockexpression_1 = _put;
          }
          _xifexpression = _xblockexpression_1;
        }
        _xblockexpression = _xifexpression;
      }
      return _xblockexpression;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  /**
   * ---------------------------------------------------------------------------
   *   Convenience methods
   */
  public JSONObject createAndRegister(final KNode node) {
    try {
      final JSONObject obj = new JSONObject();
      final String id = ("n" + Integer.valueOf(this.nodeIdCounter));
      obj.put("id", id);
      this.nodeIdCounter = (this.nodeIdCounter + 1);
      this.nodeIdMap.put(node, id);
      this.nodeJsonMap.put(node, obj);
      return obj;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public JSONObject createAndRegister(final KPort port) {
    try {
      final JSONObject obj = new JSONObject();
      final String id = ("p" + Integer.valueOf(this.portIdCounter));
      obj.put("id", id);
      this.portIdCounter = (this.portIdCounter + 1);
      this.portIdMap.put(port, id);
      this.portJsonMap.put(port, obj);
      return obj;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
  
  public JSONObject createAndRegister(final KEdge edge) {
    try {
      final JSONObject obj = new JSONObject();
      final String id = ("e" + Integer.valueOf(this.edgeIdCounter));
      obj.put("id", id);
      this.edgeIdCounter = (this.edgeIdCounter + 1);
      this.edgeIdMap.put(edge, id);
      this.edgeJsonMap.put(edge, obj);
      return obj;
    } catch (Throwable _e) {
      throw Exceptions.sneakyThrow(_e);
    }
  }
}
