/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2013 by
 * + Christian-Albrechts-University of Kiel
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.klighd.ui.wizard;

import de.cau.cs.kieler.klighd.ui.wizard.KlighdProjectInfo;
import de.cau.cs.kieler.klighd.ui.wizard.KlighdWizardSetup;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.ui.util.IProjectFactoryContributor;

/**
 * Class contains all contributions for a new KlighD project.
 * 
 * @author uru
 * @author chsch
 */
@SuppressWarnings("all")
public class KlighdProjectContributor implements IProjectFactoryContributor {
  private KlighdProjectInfo projectInfo;
  
  public KlighdProjectContributor(final KlighdProjectInfo projectInfo) {
    this.projectInfo = projectInfo;
  }
  
  public void contributeFiles(final IProject project, final IProjectFactoryContributor.IFileCreator fileWriter) {
    this.contributeBuildProperties(fileWriter);
    this.contributePluginExtensions(fileWriter);
    this.contributeJDTprefs(fileWriter);
    boolean _isCreateXtendFile = this.projectInfo.isCreateXtendFile();
    if (_isCreateXtendFile) {
      this.contributeXtendTransformationFile(fileWriter);
    } else {
      this.contributeJavaTransformationFile(fileWriter);
    }
    boolean _isCreateMenuContribution = this.projectInfo.isCreateMenuContribution();
    if (_isCreateMenuContribution) {
      this.contributeCommandHandler(fileWriter);
    }
  }
  
  /**
   * The generation of the JDT project preferences prevents any issues due to Eclipse'
   *  incompatibility with Java 1.7.<br>
   * The content has simply been copied from an instance of plug-in project with "project specific
   *  settings" using "compliance from execution environment 'J2SE-1.5' on the 'Java Build Path'".
   */
  private IFile contributeJDTprefs(final IProjectFactoryContributor.IFileCreator fileWriter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("eclipse.preferences.version=1");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.codegen.inlineJsrBytecode=enabled");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.codegen.targetPlatform=1.5");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.codegen.unusedLocal=preserve");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.compliance=1.5");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.debug.lineNumber=generate");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.debug.localVariable=generate");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.debug.sourceFile=generate");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.problem.assertIdentifier=error");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.problem.enumIdentifier=error");
    _builder.newLine();
    _builder.append("org.eclipse.jdt.core.compiler.source=1.5");
    _builder.newLine();
    return this.writeToFile(_builder, fileWriter, ((KlighdWizardSetup.SETTINGS_FOLDER + "/") + KlighdWizardSetup.JDT_PREFS_FILE));
  }
  
  private IFile contributeXtendTransformationFile(final IProjectFactoryContributor.IFileCreator fileWriter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    String _transformationPackage = this.projectInfo.getTransformationPackage();
    _builder.append(_transformationPackage, "");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("import javax.inject.Inject");
    _builder.newLine();
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.kgraph.KNode");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.KRenderingFactory");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KNodeExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KEdgeExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KPortExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KLabelExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KRenderingExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KContainerRenderingExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KPolylineExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.krendering.extensions.KColorExtensions");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.klighd.syntheses.AbstractDiagramSynthesis");
    _builder.newLine();
    _builder.newLine();
    _builder.append("import static extension de.cau.cs.kieler.klighd.syntheses.DiagramSyntheses.*");
    _builder.newLine();
    _builder.newLine();
    _builder.append("import ");
    String _sourceModelClassFullyQualified = this.projectInfo.getSourceModelClassFullyQualified();
    _builder.append(_sourceModelClassFullyQualified, "");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("class ");
    String _transformationName = this.projectInfo.getTransformationName();
    _builder.append(_transformationName, "");
    _builder.append(" extends AbstractDiagramSynthesis<");
    String _sourceModelClassSimple = this.projectInfo.getSourceModelClassSimple();
    _builder.append(_sourceModelClassSimple, "");
    _builder.append("> {");
    _builder.newLineIfNotEmpty();
    _builder.append("    ");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KNodeExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KEdgeExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KPortExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KLabelExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KRenderingExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KContainerRenderingExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KPolylineExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("@Inject extension KColorExtensions");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("extension KRenderingFactory = KRenderingFactory.eINSTANCE");
    _builder.newLine();
    _builder.append("    ");
    _builder.newLine();
    _builder.append("    ");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("override KNode transform(");
    String _sourceModelClassSimple_1 = this.projectInfo.getSourceModelClassSimple();
    _builder.append(_sourceModelClassSimple_1, "    ");
    _builder.append(" model) {");
    _builder.newLineIfNotEmpty();
    _builder.append("        ");
    _builder.append("val root = model.createNode().associateWith(model);");
    _builder.newLine();
    _builder.append("        ");
    _builder.newLine();
    _builder.append("        ");
    _builder.append("// Your dsl element <-> diagram figure mapping goes here!!");
    _builder.newLine();
    _builder.append("        ");
    _builder.newLine();
    _builder.append("        ");
    _builder.append("return root;");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("}");
    _builder.newLine();
    _builder.append("    ");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    String _transformationPath = this.getTransformationPath();
    String _plus = (_transformationPath + ".xtend");
    return this.writeToFile(_builder, fileWriter, _plus);
  }
  
  private IFile contributeJavaTransformationFile(final IProjectFactoryContributor.IFileCreator fileWriter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    String _transformationPackage = this.projectInfo.getTransformationPackage();
    _builder.append(_transformationPackage, "");
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.core.kgraph.KNode;");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.klighd.syntheses.AbstractDiagramSynthesis;");
    _builder.newLine();
    _builder.append("import ");
    String _sourceModelClassFullyQualified = this.projectInfo.getSourceModelClassFullyQualified();
    _builder.append(_sourceModelClassFullyQualified, "");
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("public class ");
    String _transformationName = this.projectInfo.getTransformationName();
    _builder.append(_transformationName, "");
    _builder.append(" extends AbstractDiagramSynthesis<");
    String _sourceModelClassSimple = this.projectInfo.getSourceModelClassSimple();
    _builder.append(_sourceModelClassSimple, "");
    _builder.append("> {");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("    ");
    _builder.append("public KNode transform(final ");
    String _sourceModelClassSimple_1 = this.projectInfo.getSourceModelClassSimple();
    _builder.append(_sourceModelClassSimple_1, "    ");
    _builder.append(" model) {");
    _builder.newLineIfNotEmpty();
    _builder.append("        ");
    _builder.append("throw new UnsupportedOperationException(\"TODO: auto-generated method stub\");");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    String _transformationPath = this.getTransformationPath();
    String _plus = (_transformationPath + ".java");
    return this.writeToFile(_builder, fileWriter, _plus);
  }
  
  private String getTransformationPath() {
    String _transformationPackage = this.projectInfo.getTransformationPackage();
    String _replace = _transformationPackage.replace(".", "/");
    String _plus = (KlighdWizardSetup.SRC_FOLDER + _replace);
    String _plus_1 = (_plus + "/");
    String _transformationName = this.projectInfo.getTransformationName();
    return (_plus_1 + _transformationName);
  }
  
  private IFile contributeBuildProperties(final IProjectFactoryContributor.IFileCreator fileWriter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("source.. = ");
    {
      boolean _isCreateXtendFile = this.projectInfo.isCreateXtendFile();
      if (_isCreateXtendFile) {
        _builder.append("xtend-gen/,\\");
      }
    }
    _builder.newLineIfNotEmpty();
    _builder.append("          ");
    _builder.append("src/");
    _builder.newLine();
    _builder.append("bin.includes = META-INF/,\\");
    _builder.newLine();
    _builder.append("        ");
    _builder.append("plugin.xml,\\");
    _builder.newLine();
    _builder.append("             ");
    _builder.append(".");
    _builder.newLine();
    return this.writeToFile(_builder, fileWriter, "build.properties");
  }
  
  private IFile contributePluginExtensions(final IProjectFactoryContributor.IFileCreator fileWriter) {
    IFile _xblockexpression = null;
    {
      StringConcatenation _builder = new StringConcatenation();
      _builder.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
      _builder.newLine();
      _builder.append("<?eclipse version=\"3.4\"?>");
      _builder.newLine();
      _builder.append("<plugin>");
      _builder.newLine();
      _builder.append("   ");
      _builder.append("<extension");
      _builder.newLine();
      _builder.append("         ");
      _builder.append("point=\"de.cau.cs.kieler.klighd.diagramSyntheses\">");
      _builder.newLine();
      _builder.append("   ");
      _builder.append("<diagramSynthesis");
      _builder.newLine();
      _builder.append("         ");
      _builder.append("class=\"de.cau.cs.kieler.klighd.syntheses.GuiceBasedSynthesisFactory:");
      String _transformationPackage = this.projectInfo.getTransformationPackage();
      String _plus = (_transformationPackage + ".");
      String _transformationName = this.projectInfo.getTransformationName();
      String _plus_1 = (_plus + _transformationName);
      _builder.append(_plus_1, "         ");
      _builder.append("\"");
      _builder.newLineIfNotEmpty();
      _builder.append("         ");
      _builder.append("id=\"");
      String _transformationPackage_1 = this.projectInfo.getTransformationPackage();
      String _plus_2 = (_transformationPackage_1 + ".");
      String _transformationName_1 = this.projectInfo.getTransformationName();
      String _plus_3 = (_plus_2 + _transformationName_1);
      _builder.append(_plus_3, "         ");
      _builder.append("\">");
      _builder.newLineIfNotEmpty();
      _builder.append("   ");
      _builder.append("</diagramSynthesis>");
      _builder.newLine();
      _builder.append("   ");
      _builder.append("</extension>");
      _builder.newLine();
      final String beginning = _builder.toString();
      String fileEndingCondition = "";
      boolean _isUseFileEnding = this.projectInfo.isUseFileEnding();
      if (_isUseFileEnding) {
        StringConcatenation _builder_1 = new StringConcatenation();
        _builder_1.append("<adapt type=\"org.eclipse.core.resources.IResource\">");
        _builder_1.newLine();
        _builder_1.append("    ");
        _builder_1.append("<test");
        _builder_1.newLine();
        _builder_1.append("          ");
        _builder_1.append("forcePluginActivation=\"false\"");
        _builder_1.newLine();
        _builder_1.append("          ");
        _builder_1.append("property=\"org.eclipse.core.resources.extension\"");
        _builder_1.newLine();
        _builder_1.append("          ");
        _builder_1.append("value=\"");
        String _fileEnding = this.projectInfo.getFileEnding();
        _builder_1.append(_fileEnding, "          ");
        _builder_1.append("\">");
        _builder_1.newLineIfNotEmpty();
        _builder_1.append("    ");
        _builder_1.append("</test>");
        _builder_1.newLine();
        _builder_1.append("</adapt>");
        _builder_1.newLine();
        fileEndingCondition = _builder_1.toString();
      }
      StringConcatenation _builder_2 = new StringConcatenation();
      _builder_2.append("<extension");
      _builder_2.newLine();
      _builder_2.append("      ");
      _builder_2.append("point=\"org.eclipse.ui.commands\">");
      _builder_2.newLine();
      _builder_2.append("   ");
      _builder_2.append("<category");
      _builder_2.newLine();
      _builder_2.append("         ");
      _builder_2.append("description=\"");
      String _sourceModelClassSimple = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple, "         ");
      _builder_2.append(" diagrams\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("         ");
      _builder_2.append("id=\"");
      String _projectName = this.projectInfo.getProjectName();
      _builder_2.append(_projectName, "         ");
      _builder_2.append(".");
      String _sourceModelClassSimple_1 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_1, "         ");
      _builder_2.append("Diagrams\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("         ");
      _builder_2.append("name=\"");
      String _sourceModelClassSimple_2 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_2, "         ");
      _builder_2.append("Diagrams\">");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("   ");
      _builder_2.append("</category>");
      _builder_2.newLine();
      _builder_2.append("   ");
      _builder_2.append("<command");
      _builder_2.newLine();
      _builder_2.append("         ");
      _builder_2.append("categoryId=\"");
      String _projectName_1 = this.projectInfo.getProjectName();
      _builder_2.append(_projectName_1, "         ");
      _builder_2.append(".");
      String _sourceModelClassSimple_3 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_3, "         ");
      _builder_2.append("Diagrams\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("         ");
      _builder_2.append("defaultHandler=\"");
      String _transformationPackage_2 = this.projectInfo.getTransformationPackage();
      String _plus_4 = (_transformationPackage_2 + ".OpenDiagramHandler");
      _builder_2.append(_plus_4, "         ");
      _builder_2.append("\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("         ");
      _builder_2.append("description=\"Primitive helper command that opens KLighD-based ");
      String _sourceModelClassSimple_4 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_4, "         ");
      _builder_2.append(" diagrams.\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("         ");
      _builder_2.append("id=\"");
      String _projectName_2 = this.projectInfo.getProjectName();
      _builder_2.append(_projectName_2, "         ");
      _builder_2.append(".open");
      String _sourceModelClassSimple_5 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_5, "         ");
      _builder_2.append("Diagram\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("         ");
      _builder_2.append("name=\"Open ");
      String _sourceModelClassSimple_6 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_6, "         ");
      _builder_2.append(" diagram\">");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("   ");
      _builder_2.append("</command>");
      _builder_2.newLine();
      _builder_2.append("</extension>");
      _builder_2.newLine();
      _builder_2.newLine();
      _builder_2.append("<extension");
      _builder_2.newLine();
      _builder_2.append("      ");
      _builder_2.append("point=\"org.eclipse.ui.menus\">");
      _builder_2.newLine();
      _builder_2.append("   ");
      _builder_2.append("<menuContribution");
      _builder_2.newLine();
      _builder_2.append("         ");
      _builder_2.append("locationURI=\"popup:org.eclipse.ui.popup.any?before=additions\">");
      _builder_2.newLine();
      _builder_2.append("      ");
      _builder_2.append("<command");
      _builder_2.newLine();
      _builder_2.append("            ");
      _builder_2.append("commandId=\"");
      String _projectName_3 = this.projectInfo.getProjectName();
      _builder_2.append(_projectName_3, "            ");
      _builder_2.append(".open");
      String _sourceModelClassSimple_7 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_7, "            ");
      _builder_2.append("Diagram\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("            ");
      _builder_2.append("label=\"Open ");
      String _sourceModelClassSimple_8 = this.projectInfo.getSourceModelClassSimple();
      _builder_2.append(_sourceModelClassSimple_8, "            ");
      _builder_2.append(" diagram\"");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("            ");
      _builder_2.append("style=\"push\">");
      _builder_2.newLine();
      _builder_2.append("         ");
      _builder_2.append("<visibleWhen");
      _builder_2.newLine();
      _builder_2.append("               ");
      _builder_2.append("checkEnabled=\"false\">");
      _builder_2.newLine();
      _builder_2.append("            ");
      _builder_2.append("<iterate ifEmpty=\"false\" operator=\"or\">");
      _builder_2.newLine();
      _builder_2.append("               ");
      _builder_2.append("<or>");
      _builder_2.newLine();
      _builder_2.append("                   ");
      _builder_2.append("<instanceof");
      _builder_2.newLine();
      _builder_2.append("                         ");
      _builder_2.append("value=\"");
      String _sourceModelClassFullyQualified = this.projectInfo.getSourceModelClassFullyQualified();
      _builder_2.append(_sourceModelClassFullyQualified, "                         ");
      _builder_2.append("\">");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("                   ");
      _builder_2.append("</instanceof>");
      _builder_2.newLine();
      _builder_2.append("                   ");
      _builder_2.append(fileEndingCondition, "                   ");
      _builder_2.newLineIfNotEmpty();
      _builder_2.append("               ");
      _builder_2.append("</or>");
      _builder_2.newLine();
      _builder_2.append("            ");
      _builder_2.append("</iterate>");
      _builder_2.newLine();
      _builder_2.append("         ");
      _builder_2.append("</visibleWhen>");
      _builder_2.newLine();
      _builder_2.append("      ");
      _builder_2.append("</command>");
      _builder_2.newLine();
      _builder_2.append("   ");
      _builder_2.append("</menuContribution>");
      _builder_2.newLine();
      _builder_2.append("</extension>");
      _builder_2.newLine();
      _builder_2.newLine();
      final String menuContribution = _builder_2.toString();
      StringConcatenation _builder_3 = new StringConcatenation();
      _builder_3.append("</plugin>");
      _builder_3.newLine();
      final String end = _builder_3.toString();
      String _xifexpression = null;
      boolean _isCreateMenuContribution = this.projectInfo.isCreateMenuContribution();
      if (_isCreateMenuContribution) {
        _xifexpression = menuContribution;
      }
      String _plus_5 = (beginning + _xifexpression);
      String _plus_6 = (_plus_5 + end);
      _xblockexpression = this.writeToFile(_plus_6, fileWriter, "plugin.xml");
    }
    return _xblockexpression;
  }
  
  private IFile contributeCommandHandler(final IProjectFactoryContributor.IFileCreator fileWriter) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("package ");
    String _transformationPackage = this.projectInfo.getTransformationPackage();
    _builder.append(_transformationPackage, "");
    _builder.append(";");
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    _builder.append("import org.eclipse.core.commands.AbstractHandler;");
    _builder.newLine();
    _builder.append("import org.eclipse.core.commands.ExecutionEvent;");
    _builder.newLine();
    _builder.append("import org.eclipse.core.commands.ExecutionException;");
    _builder.newLine();
    _builder.append("import org.eclipse.core.resources.IFile;");
    _builder.newLine();
    _builder.append("import org.eclipse.core.runtime.IStatus;");
    _builder.newLine();
    _builder.append("import org.eclipse.core.runtime.Status;");
    _builder.newLine();
    _builder.append("import org.eclipse.emf.common.util.URI;");
    _builder.newLine();
    _builder.append("import org.eclipse.emf.ecore.resource.Resource;");
    _builder.newLine();
    _builder.append("import org.eclipse.emf.ecore.resource.ResourceSet;");
    _builder.newLine();
    _builder.append("import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;");
    _builder.newLine();
    _builder.append("import org.eclipse.jface.dialogs.MessageDialog;");
    _builder.newLine();
    _builder.append("import org.eclipse.jface.viewers.ISelection;");
    _builder.newLine();
    _builder.append("import org.eclipse.jface.viewers.IStructuredSelection;");
    _builder.newLine();
    _builder.append("import org.eclipse.ui.handlers.HandlerUtil;");
    _builder.newLine();
    _builder.append("import org.eclipse.ui.statushandlers.StatusManager;");
    _builder.newLine();
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.klighd.ui.DiagramViewManager;");
    _builder.newLine();
    _builder.append("import de.cau.cs.kieler.klighd.util.KlighdSynthesisProperties;");
    _builder.newLine();
    _builder.newLine();
    _builder.append("/**");
    _builder.newLine();
    _builder.append(" ");
    _builder.append("* A simple handler for opening diagrams.");
    _builder.newLine();
    _builder.append(" ");
    _builder.append("*/");
    _builder.newLine();
    _builder.append("public class OpenDiagramHandler extends AbstractHandler {");
    _builder.newLine();
    _builder.newLine();
    _builder.append("    ");
    _builder.append("/**");
    _builder.newLine();
    _builder.append("     ");
    _builder.append("* {@inheritDoc}");
    _builder.newLine();
    _builder.append("     ");
    _builder.append("*/");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("public Object execute(final ExecutionEvent event) throws ExecutionException {");
    _builder.newLine();
    _builder.append("        ");
    _builder.append("final ISelection selection = HandlerUtil.getCurrentSelection(event);");
    _builder.newLine();
    _builder.append("        ");
    _builder.append("if (selection instanceof IStructuredSelection) {");
    _builder.newLine();
    _builder.append("            ");
    _builder.append("final IStructuredSelection sSelection  = (IStructuredSelection) selection;");
    _builder.newLine();
    _builder.append("            ");
    _builder.append("Object model = null;");
    _builder.newLine();
    _builder.append("            ");
    _builder.append("if (sSelection.getFirstElement() instanceof IFile) {");
    _builder.newLine();
    _builder.append("                ");
    _builder.append("try {");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("IFile f = (IFile) sSelection.getFirstElement();");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("ResourceSet rs = new ResourceSetImpl();");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("Resource r =");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("rs.getResource(URI.createFileURI(f.getFullPath().toString()), true);");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("if (r.getContents().size() > 0) {");
    _builder.newLine();
    _builder.append("                        ");
    _builder.append("model = r.getContents().get(0);");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("}");
    _builder.newLine();
    _builder.append("                ");
    _builder.append("} catch (Exception e) {");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("StatusManager.getManager().handle(");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("new Status(IStatus.ERROR, this.getClass().getCanonicalName(),");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("\"Could not load selected file.\", e), StatusManager.SHOW);");
    _builder.newLine();
    _builder.append("                ");
    _builder.append("}");
    _builder.newLine();
    _builder.append("            ");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("                ");
    _builder.append("model = sSelection.getFirstElement();");
    _builder.newLine();
    _builder.append("            ");
    _builder.append("}");
    _builder.newLine();
    _builder.append("            ");
    _builder.newLine();
    _builder.append("            ");
    _builder.append("DiagramViewManager.createView(");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("\"");
    String _transformationPackage_1 = this.projectInfo.getTransformationPackage();
    _builder.append(_transformationPackage_1, "                    ");
    _builder.append(".");
    String _sourceModelClassSimple = this.projectInfo.getSourceModelClassSimple();
    _builder.append(_sourceModelClassSimple, "                    ");
    _builder.append("Diagram\", \"");
    String _sourceModelClassSimple_1 = this.projectInfo.getSourceModelClassSimple();
    _builder.append(_sourceModelClassSimple_1, "                    ");
    _builder.append(" Diagram\", model, KlighdSynthesisProperties.create());");
    _builder.newLineIfNotEmpty();
    _builder.append("        ");
    _builder.append("} else {");
    _builder.newLine();
    _builder.append("            ");
    _builder.append("MessageDialog.openInformation(HandlerUtil.getActiveShell(event), \"Unsupported element\",");
    _builder.newLine();
    _builder.append("                    ");
    _builder.append("\"KLighD diagram synthesis is unsupported for the current selection \"");
    _builder.newLine();
    _builder.append("                            ");
    _builder.append("+ selection.toString() + \".\");");
    _builder.newLine();
    _builder.append("        ");
    _builder.append("}");
    _builder.newLine();
    _builder.append("        ");
    _builder.append("return null;");
    _builder.newLine();
    _builder.append("    ");
    _builder.append("}");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    String _transformationPackage_2 = this.projectInfo.getTransformationPackage();
    String _replace = _transformationPackage_2.replace(".", "/");
    String _plus = (KlighdWizardSetup.SRC_FOLDER + _replace);
    String _plus_1 = (_plus + "/OpenDiagramHandler.java");
    return this.writeToFile(_builder, fileWriter, _plus_1);
  }
  
  protected IFile writeToFile(final CharSequence chrSeq, final IProjectFactoryContributor.IFileCreator fCreator, final String fileName) {
    return fCreator.writeToFile(chrSeq, fileName);
  }
}
