/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2013 by
 * + Christian-Albrechts-University of Kiel
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.ptolemy.klighd;

import com.google.common.collect.ImmutableList;
import com.google.inject.Inject;
import de.cau.cs.kieler.core.kgraph.KNode;
import de.cau.cs.kieler.core.properties.IProperty;
import de.cau.cs.kieler.core.util.Pair;
import de.cau.cs.kieler.kiml.options.LayoutOptions;
import de.cau.cs.kieler.klay.layered.p4nodes.NodePlacementStrategy;
import de.cau.cs.kieler.klay.layered.properties.Properties;
import de.cau.cs.kieler.klighd.SynthesisOption;
import de.cau.cs.kieler.klighd.syntheses.AbstractDiagramSynthesis;
import de.cau.cs.kieler.ptolemy.klighd.transformation.CommentsExtractor;
import de.cau.cs.kieler.ptolemy.klighd.transformation.Ptolemy2KGraphOptimization;
import de.cau.cs.kieler.ptolemy.klighd.transformation.Ptolemy2KGraphTransformation;
import de.cau.cs.kieler.ptolemy.klighd.transformation.Ptolemy2KGraphVisualization;
import java.util.List;
import org.ptolemy.moml.DocumentRoot;

/**
 * Synthesis for turning Ptolemy models into KGraphs.
 * 
 * @author cds
 */
@SuppressWarnings("all")
public class PtolemyDiagramSynthesis extends AbstractDiagramSynthesis<DocumentRoot> {
  public final static String ID = "de.cau.cs.kieler.ptolemy.klighd.PtolemyDiagramSynthesis";
  
  public final static SynthesisOption SHOW_COMMENTS = SynthesisOption.createCheckOption(
    "Comments", Boolean.valueOf(true));
  
  public final static SynthesisOption SHOW_RELATIONS = SynthesisOption.createCheckOption(
    "Relations", Boolean.valueOf(false));
  
  public final static SynthesisOption COMMENT_ATTACHMENT_HEURISTIC = SynthesisOption.createCheckOption("Comment attachment heuristic", Boolean.valueOf(true));
  
  public final static SynthesisOption FLATTEN = SynthesisOption.createCheckOption(
    "Flatten Composite Actors", Boolean.valueOf(false));
  
  public final static SynthesisOption COMPOUND_NODE_ALPHA = SynthesisOption.<Float>createRangeOption(
    "Nested model darkness", Float.valueOf(0f), Float.valueOf(255f), Float.valueOf(30f));
  
  @Inject
  private Ptolemy2KGraphTransformation transformation;
  
  @Inject
  private Ptolemy2KGraphOptimization optimization;
  
  @Inject
  private Ptolemy2KGraphVisualization visualization;
  
  @Inject
  private CommentsExtractor commentsExtractor;
  
  public KNode transform(final DocumentRoot model) {
    final KNode kgraph = this.transformation.transform(model, this);
    boolean _booleanValue = this.getBooleanValue(PtolemyDiagramSynthesis.SHOW_RELATIONS);
    boolean _not = (!_booleanValue);
    boolean _booleanValue_1 = this.getBooleanValue(PtolemyDiagramSynthesis.FLATTEN);
    CommentsExtractor _xifexpression = null;
    boolean _booleanValue_2 = this.getBooleanValue(PtolemyDiagramSynthesis.SHOW_COMMENTS);
    if (_booleanValue_2) {
      _xifexpression = this.commentsExtractor;
    } else {
      _xifexpression = null;
    }
    this.optimization.optimize(kgraph, _not, _booleanValue_1, _xifexpression, this);
    int _intValue = this.getIntValue(PtolemyDiagramSynthesis.COMPOUND_NODE_ALPHA);
    this.visualization.visualize(kgraph, _intValue);
    boolean _booleanValue_3 = this.getBooleanValue(PtolemyDiagramSynthesis.SHOW_COMMENTS);
    if (_booleanValue_3) {
      boolean _booleanValue_4 = this.getBooleanValue(PtolemyDiagramSynthesis.COMMENT_ATTACHMENT_HEURISTIC);
      this.commentsExtractor.attachComments(_booleanValue_4);
    }
    return kgraph;
  }
  
  /**
   * Diagram options.
   */
  public List<SynthesisOption> getDisplayedSynthesisOptions() {
    SynthesisOption _createSeparator = SynthesisOption.createSeparator("Hierarchy");
    return ImmutableList.<SynthesisOption>of(
      PtolemyDiagramSynthesis.SHOW_COMMENTS, 
      PtolemyDiagramSynthesis.SHOW_RELATIONS, 
      PtolemyDiagramSynthesis.COMMENT_ATTACHMENT_HEURISTIC, _createSeparator, 
      PtolemyDiagramSynthesis.FLATTEN, 
      PtolemyDiagramSynthesis.COMPOUND_NODE_ALPHA);
  }
  
  /**
   * Layout options.
   */
  public List<Pair<IProperty<?>, List<?>>> getDisplayedLayoutOptions() {
    NodePlacementStrategy[] _values = NodePlacementStrategy.values();
    ImmutableList<NodePlacementStrategy> _copyOf = ImmutableList.<NodePlacementStrategy>copyOf(_values);
    Pair<IProperty<?>, List<?>> _specifyLayoutOption = this.specifyLayoutOption(Properties.NODE_PLACER, _copyOf);
    ImmutableList<Integer> _of = ImmutableList.<Integer>of(Integer.valueOf(0), Integer.valueOf(255));
    Pair<IProperty<?>, List<?>> _specifyLayoutOption_1 = this.specifyLayoutOption(LayoutOptions.SPACING, _of);
    return ImmutableList.<Pair<IProperty<?>, List<?>>>of(_specifyLayoutOption, _specifyLayoutOption_1);
  }
}
