/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2012 by
 * + Christian-Albrechts-University of Kiel
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.ptolemy.klighd.transformation.extensions;

import de.cau.cs.kieler.core.kgraph.KLabel;
import de.cau.cs.kieler.core.kgraph.KLabeledGraphElement;
import de.cau.cs.kieler.kiml.util.KimlUtil;
import org.eclipse.emf.common.util.EList;

/**
 * Utility methods for handling labels used by the Ptolemy to KGraph transformation.
 * 
 * @author cds
 * @kieler.rating yellow 2012-07-10 KI-15 cmot, grh
 * 
 * @containsExtensions ptolemy
 */
@SuppressWarnings("all")
public class LabelExtensions {
  /**
   * Sets the name of the given element by setting the text of its first label.
   * 
   * @param element the element to be named.
   * @param name the name.
   */
  public void setName(final KLabeledGraphElement element, final String name) {
    EList<KLabel> _labels = element.getLabels();
    boolean _isEmpty = _labels.isEmpty();
    if (_isEmpty) {
      KimlUtil.createInitializedLabel(element);
    }
    EList<KLabel> _labels_1 = element.getLabels();
    KLabel _get = _labels_1.get(0);
    _get.setText(name);
  }
  
  /**
   * Returns the name of the given element. Its name is assumed to be the text of its first label.
   * 
   * @param element the element whose name to return.
   * @return the element's name or the empty string if none could be found.
   */
  public String getName(final KLabeledGraphElement element) {
    EList<KLabel> _labels = element.getLabels();
    boolean _isEmpty = _labels.isEmpty();
    if (_isEmpty) {
      return "";
    } else {
      EList<KLabel> _labels_1 = element.getLabels();
      KLabel _get = _labels_1.get(0);
      return _get.getText();
    }
  }
}
