/**
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 * 
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2012 by
 * + Christian-Albrechts-University of Kiel
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.ptolemy.klighd.transformation.extensions;

import de.cau.cs.kieler.ptolemy.klighd.transformation.util.TransformationConstants;

/**
 * Utility methods for coping with ports used by the Ptolemy to KGraph transformation.
 * 
 * @author cds
 * @kieler.rating yellow 2012-07-10 KI-15 cmot, grh
 * 
 * @containsExtensions
 */
@SuppressWarnings("all")
public class PortExtensions {
  /**
   * Checks if the given name is a name usual for input ports.
   * 
   * @param name the name of the port to check.
   * @return {@code true} if the name is common for input ports, {@code false} otherwise.
   */
  public boolean isInputPortName(final String name) {
    for (final String inputPortName : TransformationConstants.PORT_NAMES_INPUT) {
      boolean _equals = inputPortName.equals(name);
      if (_equals) {
        return true;
      }
    }
    return false;
  }
  
  /**
   * Checks if the given name is a name usual for output ports.
   * 
   * @param name the name of the port to check.
   * @return {@code true} if the name is common for output ports, {@code false} otherwise.
   */
  public boolean isOutputPortName(final String name) {
    for (final String inputPortName : TransformationConstants.PORT_NAMES_OUTPUT) {
      boolean _equals = inputPortName.equals(name);
      if (_equals) {
        return true;
      }
    }
    return false;
  }
}
